bibentry(bibtype = "Article",
         key = "Baillie:1996",
         title = "Long Memory Processes and Fractional Integration in Econometrics",
         volume = "73",
         .issn = "0304-4076",
         doi = "10.1016/0304-4076(95)01732-1",
         number = "1",
         journal = "Journal of Econometrics",
         publisher = "Elsevier BV",
         author = person(given = c("Richard", "T."),
                         family = "Baillie"),
         year = "1996",
         month = "jul",
         pages = "5--59")

bibentry(bibtype = "Article",
         key = "Bera+Higgins:1993",
         title = "{ARCH} Models: Properties, Estimation and Testing",
         volume = "7",
         .issn = "1467-6419",
         doi = "10.1111/j.1467-6419.1993.tb00170.x",
         number = "4",
         journal = "Journal of Economic Surveys",
         publisher = "Wiley",
         author = c(person(given = c("Anil", "K."),
                           family = "Bera"),
                    person(given = c("Matthew", "L."),
                           family = "Higgins")),
         year = "1993",
         month = "dec",
         pages = "305--366")

bibentry(bibtype = "Article",
         key = "Bollerslev:1986",
         title = "Generalized Autoregressive Conditional Heteroskedasticity",
         volume = "31",
         .issn = "0304-4076",
         doi = "10.1016/0304-4076(86)90063-1",
         number = "3",
         journal = "Journal of Econometrics",
         publisher = "Elsevier BV",
         author = person(given = "Tim",
                         family = "Bollerslev"),
         year = "1986",
         month = "apr",
         pages = "307--327")

bibentry(bibtype = "Book",
         key = "Cromwell+Labys+Terraza:1994",
         author = c(person(given = "Jeff",
                           family = "Cromwell"),
                    person(given = "Walter",
                           family = "Labys"),
                    person(given = "Michel",
                           family = "Terraza")),
         title = "Univariate Tests for Time Series Models",
         publisher = "Sage Publications",
         year = "1994",
         address = "Thousand Oaks, California",
         doi = "10.4135/9781412986458")

bibentry(bibtype = "Article",
         key = "Dennis+Gay+Welsch:1981",
         title = "Algorithm 573: {NL2SOL}--An Adaptive Nonlinear Least-Squares Algorithm",
         volume = "7",
         .issn = "1557-7295",
         doi = "10.1145/355958.355966",
         number = "3",
         journal = "ACM Transactions on Mathematical Software",
         publisher = "Association for Computing Machinery (ACM)",
         author = c(person(given = c("John", "E."),
                           family = "Dennis"),
                    person(given = c("David", "M."),
                           family = "Gay"),
                    person(given = c("Roy", "E."),
                           family = "Welsch")),
         year = "1981",
         month = "sep",
         pages = "369--383")

bibentry(bibtype = "Article",
         key = "Dennis+Mei:1979",
         title = "Two New Unconstrained Optimization Algorithms which Use Function and Gradient Values",
         volume = "28",
         .issn = "1573-2878",
         doi = "10.1007/bf00932218",
         number = "4",
         journal = "Journal of Optimization Theory and Applications",
         publisher = "Springer Science and Business Media LLC",
         author = c(person(given = c("J.", "E."),
                           family = "Dennis"),
                    person(given = c("H.", "H.", "W."),
                           family = "Mei")),
         year = "1979",
         month = "aug",
         pages = "453--482")

bibentry(bibtype = "Article",
         key = "Dennis+Moré:1977",
         title = "Quasi-Newton Methods, Motivation and Theory",
         volume = "19",
         .issn = "1095-7200",
         doi = "10.1137/1019005",
         number = "1",
         journal = "SIAM Review",
         publisher = "Society for Industrial & Applied Mathematics (SIAM)",
         author = c(person(given = c("J.", "E."),
                           family = "Dennis Jr."),
                    person(given = c("Jorge", "J."),
                           family = "Moré")),
         year = "1977",
         month = "jan",
         pages = "46--89")

bibentry(bibtype = "Book",
         key = "Elton+Gruber:1991",
         author = c(person(given = c("E.", "J."),
                           family = "Elton"),
                    person(given = c("M.", "J."),
                           family = "Gruber")),
         title = "Modern Portfolio Theory and Investment Analysis",
         publisher = "Wiley",
         year = "1991",
         address = "New York",
         edition = "Fourth")

bibentry(bibtype = "Article",
         key = "Engle:1982",
         author = person(given = c("Robert", "F."),
                         family = "Engle"),
         title = "Autoregressive Conditional Heteroscedasticity with Estimates of the Variance of {United Kingdom} Inflation",
         journal = "Econometrica",
         year = "1982",
         volume = "50",
         number = "4",
         pages = "987--1008",
         doi = "10.2307/1912773")

bibentry(bibtype = "Article",
         key = "Goldfarb:1976",
         title = "Factorized Variable Metric Methods for Unconstrained Optimization",
         volume = "30",
         .issn = "1088-6842",
         doi = "10.1090/s0025-5718-1976-0423804-2",
         number = "136",
         journal = "Mathematics of Computation",
         publisher = "American Mathematical Society (AMS)",
         author = person(given = "Donald",
                         family = "Goldfarb"),
         year = "1976",
         pages = "796--811")

bibentry(bibtype = "Article",
         key = "Hannan+Rissanen:1982",
         title = "Recursive Estimation of Mixed Autoregressive-Moving Average Order",
         volume = "69",
         .issn = "1464-3510",
         doi = "10.1093/biomet/69.1.81",
         number = "1",
         journal = "Biometrika",
         publisher = "Oxford University Press (OUP)",
         author = c(person(given = c("E.", "J."),
                           family = "Hannan"),
                    person(given = "J.",
                           family = "Rissanen")),
         year = "1982",
         pages = "81--94")

bibentry(bibtype = "Book",
         key = "Huang+Litzenberger:1988",
         author = c(person(given = "C.",
                           family = "Huang"),
                    person(given = c("R.", "H."),
                           family = "Litzenberger")),
         title = "Foundations for Financial Economics",
         publisher = "Elsevier",
         year = "1988",
         address = "New York")

bibentry(bibtype = "Article",
         key = "Koop+Steel:1994",
         title = "A Decision-Theoretic Analysis of the Unit-Root Hypothesis Using Mixtures of Elliptical Models",
         volume = "12",
         .issn = "1537-2707",
         doi = "10.1080/07350015.1994.10509993",
         number = "1",
         journal = "Journal of Business & Economic Statistics",
         publisher = "Informa UK Limited",
         author = c(person(given = "Gary",
                           family = "Koop"),
                    person(given = c("Mark", "F.", "J."),
                           family = "Steel")),
         year = "1994",
         month = "jan",
         pages = "95--107")

bibentry(bibtype = "Article",
         key = "Lee+White+Granger:1993",
         title = "Testing for Neglected Nonlinearity in Time Series Models",
         volume = "56",
         .issn = "0304-4076",
         doi = "10.1016/0304-4076(93)90122-l",
         number = "3",
         journal = "Journal of Econometrics",
         publisher = "Elsevier BV",
         author = c(person(given = "Tae-Hwy",
                           family = "Lee"),
                    person(given = "Halbert",
                           family = "White"),
                    person(given = c("Clive", "W.", "J."),
                           family = "Granger")),
         year = "1993",
         month = "apr",
         pages = "269--290")

bibentry(bibtype = "Article",
         key = "Kunsch:1989",
         title = "The Jackknife and the Bootstrap for General Stationary Observations",
         volume = "17",
         .issn = "0090-5364",
         doi = "10.1214/aos/1176347265",
         number = "3",
         journal = "The Annals of Statistics",
         publisher = "Institute of Mathematical Statistics",
         author = person(given = c("Hans", "R."),
                         family = "Kunsch"),
         year = "1989",
         month = "sep")

bibentry(bibtype = "Article",
         key = "Kwiatkowski+Phillips+Schmidt:1992",
         title = "Testing the Null Hypothesis of Stationarity Against the Alternative of a Unit Root",
         volume = "54",
         .issn = "0304-4076",
         doi = "10.1016/0304-4076(92)90104-y",
         number = "1--3",
         journal = "Journal of Econometrics",
         publisher = "Elsevier BV",
         author = c(person(given = "Denis",
                           family = "Kwiatkowski"),
                    person(given = c("Peter", "C.", "B."),
                           family = "Phillips"),
                    person(given = "Peter",
                           family = "Schmidt"),
                    person(given = "Yongcheol",
                           family = "Shin")),
         year = "1992",
         month = "oct",
         pages = "159--178")

bibentry(bibtype = "Article",
         key = "Nelson+Plosser:1982",
         title = "Trends and Random Walks in Macroeconmic Time Series",
         volume = "10",
         .issn = "0304-3932",
         doi = "10.1016/0304-3932(82)90012-5",
         number = "2",
         journal = "Journal of Monetary Economics",
         publisher = "Elsevier BV",
         author = c(person(given = c("Charles", "R."),
                           family = "Nelson"),
                    person(given = c("Charles", "R."),
                           family = "Plosser")),
         year = "1982",
         month = "jan",
         pages = "139--162")

bibentry(bibtype = "Article",
         key = "Perron:1988",
         title = "Trends and Random Walks in Macroeconomic Time Series",
         volume = "12",
         .issn = "0165-1889",
         doi = "10.1016/0165-1889(88)90043-7",
         number = "2--3",
         journal = "Journal of Economic Dynamics and Control",
         publisher = "Elsevier BV",
         author = person(given = "Pierre",
                         family = "Perron"),
         year = "1988",
         month = "jun",
         pages = "297--332")

bibentry(bibtype = "Article",
         key = "Phillips+Ouliaris:1990",
         title = "Asymptotic Properties of Residual Based Tests for Cointegration",
         volume = "58",
         .issn = "0012-9682",
         doi = "10.2307/2938339",
         number = "1",
         journal = "Econometrica",
         publisher = "JSTOR",
         author = c(person(given = c("P.", "C.", "B."),
                           family = "Phillips"),
                    person(given = "S.",
                           family = "Ouliaris")),
         year = "1990",
         month = "jan",
         pages = "165")

bibentry(bibtype = "Article",
         key = "Politis+Romano:1994",
         title = "The Stationary Bootstrap",
         volume = "89",
         .issn = "1537-274X",
         doi = "10.1080/01621459.1994.10476870",
         number = "428",
         journal = "Journal of the American Statistical Association",
         publisher = "Informa UK Limited",
         author = c(person(given = c("Dimitris", "N."),
                           family = "Politis"),
                    person(given = c("Joseph", "P."),
                           family = "Romano")),
         year = "1994",
         month = "dec",
         pages = "1303--1313")

bibentry(bibtype = "Article",
         key = "Said+Dickey:1984",
         title = "Testing for Unit Roots in Autoregressive-Moving Average Models of Unknown Order",
         volume = "71",
         .issn = "1464-3510",
         doi = "10.1093/biomet/71.3.599",
         number = "3",
         journal = "Biometrika",
         publisher = "Oxford University Press (OUP)",
         author = c(person(given = c("Said", "E."),
                           family = "Said"),
                    person(given = c("David", "A."),
                           family = "Dickey")),
         year = "1984",
         pages = "599--607")

bibentry(bibtype = "Book",
         key = "Siegel:1956",
         author = person(given = "S.",
                         family = "Siegel"),
         title = "Nonparametric Statistics for the Behavioural Sciences",
         publisher = "McGraw-Hill",
         year = "1956",
         address = "New York")

bibentry(bibtype = "Book",
         key = "Siegel+Castellan:1988",
         author = c(person(given = "S.",
                           family = "Siegel"),
                    person(given = c("N.", "J."),
                           family = "Castellan")),
         title = "Nonparametric Statistics for the Behavioural Sciences",
         publisher = "McGraw-Hill",
         year = "1988",
         address = "New York",
         edition = "Second")

bibentry(bibtype = "InCollection",
         key = "Theiler+Galdrikian+Longtin:1992",
         author = c(person(given = "J.",
                           family = "Theiler"),
                    person(given = "B.",
                           family = "Galdrikian"),
                    person(given = "A.",
                           family = "Longtin"),
                    person(given = "S.",
                           family = "Eubank"),
                    person(given = c("J.", "D."),
                           family = "Farmer")),
         title = "Using Surrogate Data to Detect Nonlinearity in Time Series",
         booktitle = "Nonlinear Modelling and Forecasting",
         publisher = "Addison Wesley",
         year = "1992",
         editor = c(person(given = "M.",
                           family = "Casdagli"),
                    person(given = "S.",
                           family = "Eubank")),
         pages = "163--188")

bibentry(bibtype = "Article",
         key = "Teräsvirta+Lin+Granger:1993",
         title = "Power of the Neural Network Linearity Test",
         volume = "14",
         .issn = "1467-9892",
         doi = "10.1111/j.1467-9892.1993.tb00139.x",
         number = "2",
         journal = "Journal of Time Series Analysis",
         publisher = "Wiley",
         author = c(person(given = "Timo",
                           family = "Teräsvirta"),
                    person(given = c("Clive", "W.", "J."),
                           family = "Granger"),
                    person(given = "Chien‐Fu",
                           family = "Lin")),
         year = "1993",
         month = "mar",
         pages = "209--220")

bibentry(bibtype = "Book",
         key = "Tong:1990",
         author = person(given = "Howell",
                         family = "Tong"),
         title = "Non-Linear Time Series: A Dynamical System Approach",
         publisher = "Oxford University Press",
         year = "1990",
         month = "08",
         isbn = "9780198522249",
         doi = "10.1093/oso/9780198522249.001.0001")

bibentry(bibtype = "Article",
         key = "Tong+Thanoon+Gudmundsson:1985",
         title = "Threshold Time Series Modeling of two Icelandic Riverflow Systems",
         volume = "21",
         .issn = "1752-1688",
         doi = "10.1111/j.1752-1688.1985.tb05380.x",
         number = "4",
         journal = "JAWRA Journal of the American Water Resources Association",
         publisher = "Wiley",
         author = c(person(given = "H.",
                           family = "Tong"),
                    person(given = "B.",
                           family = "Thanoon"),
                    person(given = "G.",
                           family = "Gudmundsson")),
         year = "1985",
         month = "aug",
         pages = "651--662")



